==> sassphp_0.5.16.orig.tar.gz: sassphp-0.5.16/README.md <==
# sassphp

The `sass` extension for PHP gives you an object-oriented system of parsing [Sass](http://sass-lang.com/) from within your PHP applications. Under the hood it uses [libsass](https://github.com/hcatlin/libsass) to provide super speedy and compatible Sass parsing.

![Libsass 3.5.4](https://img.shields.io/badge/libsass-3.5.4-yellow.svg) [![Build Status](https://travis-ci.org/absalomedia/sassphp.svg)](https://travis-ci.org/absalomedia/sassphp)

## What's Sass?

Sass is a CSS pre-processor language to add on exciting, new, awesome features to CSS. Sass was the first language of its kind and by far the most mature and up to date codebase.

Sass was originally created by Hampton Catlin ([@hcatlin](http://twitter.com/hcatlin)). The extension and continuing evolution of the language has all been the result of years of work by Natalie Weizenbaum ([@nex3](http://twitter.com/nex3)) and Chris Eppstein ([@chriseppstein](http://twitter.com/chriseppstein)).

For more information about Sass itself, please visit [http://sass-lang.com](http://sass-lang.com)

## Installation

Currently, the only way to install the extension is manually:

    $ git clone git://github.com/absalomedia/sassphp

Remember to grab your submodules:

    $ git submodule init
    $ git submodule update

Also remember that libsass now uses submodules on its own, so update those too.

...and compile it! I've written a little PHP script to do all the stuff you need to do:

    $ php install.php

Run the tests:

    $ make test

Finally, you can install with `make`:

    $ make install

And then add it to your _php.ini_:

    extension=sass.so

## Usage

This extension has a very simple API:

    $sass = new Sass();
    $css = $sass->compile($source);

You can compile a file with `compileFile()`:

    $sass = new Sass();
    $css = $sass->compileFile($source);

You can set the include path for the library to use:

    $sass = new Sass();
    $sass->setIncludePath('/tmp');
    $css = $sass->compile($source);

You can set the style of your SASS file to suit your needs:

    $sass = new Sass();
    $sass->setStyle(Sass::STYLE_NESTED);

    $sass = new Sass();
    $sass->setStyle(Sass::STYLE_EXPANDED);

    $sass = new Sass();
    $sass->setStyle(Sass::STYLE_COMPACT);

    $sass = new Sass();
    $sass->setStyle(Sass::STYLE_COMPRESSED);

As the [Libsass](https://github.com/hcatlin/libsass) library has matured to get closer to 100% SASS coverage, so this extension has also matured:

* SASS file compilation is an array when a source map file is specified.
* The ability to define source comments
* The ability to embed the source map into the CSS output
* The ability to specify .SASS file input instead of .SCSS
* The ability to set a source map path, required when generating a dedicated .map file
* The ability to define a root directory for the source map itself
* PHP 5.4 to PHP 7.3 (nightly) support

The output of `compileFile()` is an array when creating source map files, allowing both compiled SASS file and .map file to be generated in the same function call.

As there are multiple ways of generating source comments, there are now PHP level settings to control that output.

To generate source comments for a file inline:

    $sass = new Sass();
    $sass->setComments(true);
    $css = $sass->compileFile($source);

Aliases also exist so you can also use:

    $css = $sass->compile_file($source);

You can tell the compiler to use indented syntax (SASS syntax). By default it expects SCSS syntax:

    $sass = new Sass();
    $sass->setIndent(true); //TRUE -> SASS, FALSE -> SCSS
    $css = $sass->compile($source);

You can tell the compiler to embed the source map into the actual CSS file as well:

    $sass = new Sass();
    $sass->setEmbed(true);
    $css = $sass->compile($source);

You can set the source map file for the library to use:

    $sass = new Sass();
    $sass->setMapPath('/random.output.css.map');
    $css = $sass->compileFile($source);

This needs to be done prior to getting the output of the map file. As it stands, both the output of the SASS file compile & the SASS source map file generation sequence are both strings.

The first array item will always be the compiled SASS file:
$css[0]

The second array item will always be the source map output:
$css[1]

You can set the root of the generated source map file like so:

    $sass = new Sass();
    $sass->setMapRoot('/some/dir');
    $sass->setMapPath('/random.output.css.map');
    $css = $sass->compileFile($source);

If there's a problem, the extension will throw a `SassException`:

    $sass = new Sass();

    try
    {
        $css = $sass->compile('dayrui3dui36di37');
    }
    catch (SassException $e)
    {
        // $e->getMessage() - ERROR -- , line 1: invalid top-level expression

        $css = FALSE;
    }

## Variant builds

These extensions also utilise the [Libsass](https://github.com/hcatlin/libsass) library & remain in varying states of completion:

* Facebook [HHVM](https://github.com/absalomedia/sasshhvm) native (non Zend) extension - with Libsass 3.5.2 - tested up to HHVM 3.11.x
* [Nginx](https://github.com/absalomedia/sass-nginx-module) module - with Libsass 3.5.2

## Changelog

| Release | Description                                                                               |
| ------- | ----------------------------------------------------------------------------------------- |
| 0.5.16  | Humpback - Maloo (Libsass 3.5.4)                                                          |
| 0.5.15  | Fallout - Atom (Libsass 3.5.2)                                                            |
| 0.5.14  | Karol - Caroline (Libsass 3.4.8)                                                          |
| 0.5.13  | Ray - Manta (Libsass 3.4.5) & PHP stub file                                               |
| 0.5.12  | Cartography - MapRoot functions                                                           |
| 0.5.11  | Zoomer (Libsass 3.4.4) stable                                                             |
| 0.5.10  | Elwood (Libsass 3.4.3) stable & Travis fix                                                |
| 0.5.9   | Rickshaw (Libsass 3.4.2) stable                                                           |
| 0.5.8   | AI - KITT (Libsass 3.4.0) stable                                                          |
| 0.5.7   | Hancock - Optimise loops & Travis. Simplify changelog documentation                       |
| 0.5.6   | Green Giant - PHP5 & PHP7 stable build - All Travis builds passing                        |
| 0.5.5   | Herbie (Libsass 3.3.6) stable                                                             |
| 0.5.2   | Delorean (Libsass 3.3.3) stable & continuing PHP7 rewrite                                 |
| 0.5.1   | Eleanor (Libsass 3.3.2) stable                                                            |
| 0.5.0   | Start of PHP 7 compatibility                                                              |
| 0.4.9   | Too Fast To Furious (Libsass 3.3.1) stable                                                |
| 0.4.8   | Greased Lightning (Libsass 3.3.0) stable                                                  |
| 0.4.7   | SCSS vs SASS detection - indents                                                          |
| 0.4.6   | Travis experimental (unreleased)                                                          |
| 0.4.5   | Holiday Patch (Libsass 3.2.5) stable                                                      |
| 0.4.4   | Refactor correctly for LibSass 3.2.4                                                      |
| 0.4.2   | CamelCase compile sequence                                                                |
| 0.4.1   | Addition of SOURCE_DEFAULT test & structure. Revise other tests                           |
| 0.4.0   | Refactor file compliation. Basic tests for source comments. Expand documentation          |
| 0.3.9   | Addition of source map url paths to SASS file compilation                                 |
| 0.3.5   | Restructure of compile sequence (file only at this time) to account for source map output |
| 0.3.0   | Addition of source comments - none, inline, file. Set default to none.                    |
| 0.2.0   | Changed methods to be non-static. Allow setting include-path and image-path               |
| 0.1.0   | Initial release                                                                           |

==> sassphp_0.7.orig.tar.gz: sassphp-0.7/README.md <==
# sassphp

The `sass` extension for PHP gives you an object-oriented system of parsing [Sass](http://sass-lang.com/) from within your PHP applications. Under the hood it uses [libsass](https://github.com/hcatlin/libsass) to provide super speedy and compatible Sass parsing.

![Libsass 3.6.3](https://img.shields.io/badge/libsass-3.6.3-yellow.svg) [![Build Status](https://travis-ci.org/absalomedia/sassphp.svg)](https://travis-ci.org/absalomedia/sassphp) [![codecov](https://codecov.io/gh/absalomedia/sassphp/branch/master/graph/badge.svg)](https://codecov.io/gh/absalomedia/sassphp) [![Patreon](https://img.shields.io/badge/patreon-donate-green.svg)](https://www.patreon.com/bePatron?u=14641360)

## What's Sass?

Sass is a CSS pre-processor language to add on exciting, new, awesome features to CSS. Sass was the first language of its kind and by far the most mature and up to date codebase.

Sass was originally created by Hampton Catlin ([@hcatlin](http://twitter.com/hcatlin)). The extension and continuing evolution of the language has all been the result of years of work by Natalie Weizenbaum ([@nex3](http://twitter.com/nex3)) and Chris Eppstein ([@chriseppstein](http://twitter.com/chriseppstein)).

For more information about Sass itself, please visit [http://sass-lang.com](http://sass-lang.com)

## Installation

Currently, the only way to install the extension is manually:

    $ git clone git://github.com/absalomedia/sassphp

Remember to grab your submodules:

    $ git submodule init
    $ git submodule update

Also remember that libsass now uses submodules on its own, so update those too.

...and compile it! I've written a little PHP script to do all the stuff you need to do:

    $ php install.php

Run the tests:

    $ make test

Finally, you can install with `make`:

    $ make install

And then add it to your _php.ini_:

    extension=sass.so

Always remember to enable it within PHP as well

    phpenmod sass

## Binary installation / deployment

As long as you have the final 'sass.so' extension file, you can deploy SASS PHP across any server. There's a few caveats, of course. The development & production servers have to run the same version of PHP. You then copy the installed 'sass.so' from the /usr/lib/php/<php version> directory shown during 'make install' on your development environment to the same directory on your production boxes.

As usual, make sure you add the extension to your _php.ini_ on your production environments:

    extension=sass.so

Always remember to enable it within PHP as well

    phpenmod sass

## Usage

This extension has a very simple API:

    $sass = new Sass();
    $css = $sass->compile($source);

You can compile a file with `compileFile()`:

    $sass = new Sass();
    $css = $sass->compileFile($source);

You can set the include path for the library to use:

    $sass = new Sass();
    $sass->setIncludePath('/tmp');
    $css = $sass->compile($source);

You can set the style of your SASS file to suit your needs:

    $sass = new Sass();
    $sass->setStyle(Sass::STYLE_NESTED);

    $sass = new Sass();
    $sass->setStyle(Sass::STYLE_EXPANDED);

    $sass = new Sass();
    $sass->setStyle(Sass::STYLE_COMPACT);

    $sass = new Sass();
    $sass->setStyle(Sass::STYLE_COMPRESSED);

As the [Libsass](https://github.com/hcatlin/libsass) library has matured to get closer to 100% SASS coverage, so this extension has also matured:

- SASS file compilation is an array when a source map file is specified.
- The ability to define source comments
- The ability to embed the source map into the CSS output
- The ability to specify .SASS file input instead of .SCSS
- The ability to set a source map path, required when generating a dedicated .map file
- The ability to define a root directory for the source map itself
- SASS importer & functions capabilities
- PHP 7.0 to PHP 7.4 support, with tests for PHP 8

The output of `compileFile()` is an array when creating source map files, allowing both compiled SASS file and .map file to be generated in the same function call.

As there are multiple ways of generating source comments, there are now PHP level settings to control that output.

To generate source comments for a file inline:

    $sass = new Sass();
    $sass->setComments(true);
    $css = $sass->compileFile($source);

Aliases also exist so you can also use:

    $css = $sass->compile_file($source);

You can tell the compiler to use indented syntax (SASS syntax). By default it expects SCSS syntax:

    $sass = new Sass();
    $sass->setIndent(true); //TRUE -> SASS, FALSE -> SCSS
    $css = $sass->compile($source);

You can tell the compiler to embed the source map into the actual CSS file as well:

    $sass = new Sass();
    $sass->setEmbed(true);
    $css = $sass->compile($source);

You can set the source map file for the library to use:

    $sass = new Sass();
    $sass->setMapPath('/random.output.css.map');
    $css = $sass->compileFile($source);

This needs to be done prior to getting the output of the map file. As it stands, both the output of the SASS file compile & the SASS source map file generation sequence are both strings.

The first array item will always be the compiled SASS file:
\$css[0]

The second array item will always be the source map output:
\$css[1]

You can set the root of the generated source map file like so:

    $sass = new Sass();
    $sass->setMapRoot('/some/dir');
    $sass->setMapPath('/random.output.css.map');
    $css = $sass->compileFile($source);

If there's a problem, the extension will throw a `SassException`:

    $sass = new Sass();

    try
    {
        $css = $sass->compile('dayrui3dui36di37');
    }
    catch (SassException $e)
    {
        // $e->getMessage() - ERROR -- , line 1: invalid top-level expression

        $css = FALSE;
    }

## Variant builds

These extensions also utilise the [Libsass](https://github.com/hcatlin/libsass) library & remain in varying states of completion:

- Facebook [HHVM](https://github.com/absalomedia/sasshhvm) native (non Zend) extension - with Libsass 3.5.5 - tested up to HHVM 3.11.x
- [Nginx](https://github.com/absalomedia/sass-nginx-module) module - with Libsass 3.5.5

## Changelog

| Release | Description                                                                               |
| ------- | ----------------------------------------------------------------------------------------- |
| 0.7.0   | Librarian - Functions & importers                                                         |
| 0.6.2   | Solskjær - Manchester (Libsass 3.6.3)                                                     |
| 0.6.1   | Bond - Monaco (Libsass 3.6.1)                                                             |
| 0.6.0   | Symfony - Composer integration                                                            |
| 0.5.17  | Engine - Vroom vroom (Libsass 3.5.5)                                                      |
| 0.5.16  | Humpback - Maloo (Libsass 3.5.4)                                                          |
| 0.5.15  | Fallout - Atom (Libsass 3.5.2)                                                            |
| 0.5.14  | Karol - Caroline (Libsass 3.4.8)                                                          |
| 0.5.13  | Ray - Manta (Libsass 3.4.5) & PHP stub file                                               |
| 0.5.12  | Cartography - MapRoot functions                                                           |
| 0.5.11  | Zoomer (Libsass 3.4.4) stable                                                             |
| 0.5.10  | Elwood (Libsass 3.4.3) stable & Travis fix                                                |
| 0.5.9   | Rickshaw (Libsass 3.4.2) stable                                                           |
| 0.5.8   | AI - KITT (Libsass 3.4.0) stable                                                          |
| 0.5.7   | Hancock - Optimise loops & Travis. Simplify changelog documentation                       |
| 0.5.6   | Green Giant - PHP5 & PHP7 stable build - All Travis builds passing                        |
| 0.5.5   | Herbie (Libsass 3.3.6) stable                                                             |
| 0.5.2   | Delorean (Libsass 3.3.3) stable & continuing PHP7 rewrite                                 |
| 0.5.1   | Eleanor (Libsass 3.3.2) stable                                                            |
| 0.5.0   | Start of PHP 7 compatibility                                                              |
| 0.4.9   | Too Fast To Furious (Libsass 3.3.1) stable                                                |
| 0.4.8   | Greased Lightning (Libsass 3.3.0) stable                                                  |
| 0.4.7   | SCSS vs SASS detection - indents                                                          |
| 0.4.6   | Travis experimental (unreleased)                                                          |
| 0.4.5   | Holiday Patch (Libsass 3.2.5) stable                                                      |
| 0.4.4   | Refactor correctly for LibSass 3.2.4                                                      |
| 0.4.2   | CamelCase compile sequence                                                                |
| 0.4.1   | Addition of SOURCE_DEFAULT test & structure. Revise other tests                           |
| 0.4.0   | Refactor file compliation. Basic tests for source comments. Expand documentation          |
| 0.3.9   | Addition of source map url paths to SASS file compilation                                 |
| 0.3.5   | Restructure of compile sequence (file only at this time) to account for source map output |
| 0.3.0   | Addition of source comments - none, inline, file. Set default to none.                    |
| 0.2.0   | Changed methods to be non-static. Allow setting include-path and image-path               |
| 0.1.0   | Initial release                                                                           |
